==> mediawiki-1.13.3.tar.gz: mediawiki-1.13.3/languages/messages/MessagesAy.php <==
<?php
/** Aymara (Aymar aru)
 *
 * @ingroup Language
 * @file
 *
 * @author Erebedhel
 * @author Kanon6917
 */

$fallback = 'es';

$messages = array(
# User preference toggles
'tog-underline'               => 'Sipita siqiraña',
'tog-highlightbroken'         => 'P\'akita sipita utt\'ayaña <a href="" class="new">ukhama</a> (maykipa: ukhama<a href="" class="internal">?</a>).',
'tog-justify'                 => "Tanta amuyanak purapt'ayaña",
'tog-hideminor'               => 'Jichha kutikiptatanakana «Janiw taqpachäkiti» imantaña',
'tog-extendwatchlist'         => "Sarayawi jaqukipaw uñachayasuñatakiw unch'ukit waruch aqatatayaña",
'tog-usenewrc'                => "Jichhnaki jaqukipawi waliptäta (''JavaScript'')",
'tog-numberheadings'          => 'Titulun chinu achuraña',
'tog-showtoolbar'             => "Turkawit irnaqañ täta tisi uñachayaña (''JavaScript'')",
'tog-editondblclick'          => "Uñstawi turkayaña päsuxuqiña (''JavaScript'')",
'tog-editsection'             => '[Turkaña] sipitampi tuqitaki turkawi luräña',
'tog-editsectiononrightclick' => "(''JavaScript'') titulxat tuqina kupi suxuqiñampi tuqitaki turkawi luräña",
'tog-showtoc'                 => 'Waruchataw uñachayaña (kimsa tituljampi uñstawitaki)',
'tog-rememberpassword'        => "Akax jasanchirin imt'awija amtaña",

'underline-always' => 'Wiñaya',
'underline-never'  => 'Janipini',

# Dates
'sunday'        => 'tuminku',
'monday'        => 'lunisa',
'tuesday'       => 'martisa',
'wednesday'     => 'mirkulisa',
'thursday'      => 'juywisa',
'friday'        => 'wirnisa',
'saturday'      => 'sawaru',
'sun'           => 'tum',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mir',
'thu'           => 'juy',
'fri'           => 'wir',
'sat'           => 'saw',
'january'       => 'chichu phaxsi',
'february'      => 'anata phaxsi',
'march'         => 'achuqa phaxsi',
'april'         => 'yapu apthapi phaxsi',
'may_long'      => 'llamayu phaxsi',
'june'          => 'juyphi phaxsi',
'july'          => 'huillka kuti phaxsi',
'august'        => 'thaya phaxsi',
'september'     => "llamp'u phaxsi",
'october'       => 'taypi sata phaxsi',
'november'      => 'awti phaxsi',
'december'      => 'jallu qallta phaxsi',
'january-gen'   => 'chichu phaxsi',
'february-gen'  => 'anata phaxsi',
'march-gen'     => 'achuqa phaxsi',
'april-gen'     => 'yapu apthapi phaxsi',
'may-gen'       => 'llamayu phaxsi',
'june-gen'      => 'juyphi phaxsi',
'july-gen'      => 'huillka kuti phaxsi',
'august-gen'    => 'thaya phaxsi',
'september-gen' => "llamp'u phaxsi",
'october-gen'   => 'taypi sata phaxsi',
'november-gen'  => 'awti phaxsi',
'december-gen'  => 'jallu qallta phaxsi',
'jan'           => 'chi',
'feb'           => 'ana',
'mar'           => 'ach',
'apr'           => 'yap',
'may'           => 'llam',
'jun'           => 'juy',
'jul'           => 'hui',
'aug'           => 'tha',
'sep'           => 'llmp',
'oct'           => 'tay',
'nov'           => 'awt',
'dec'           => 'jall',

'article'       => 'Amtachinu',
'cancel'        => 'Jan saña',
'qbfind'        => 'Thaqaña',
'qbbrowse'      => 'Wampuña',
'qbedit'        => 'Turkaña',
'qbpageoptions' => 'Uñstawitaki ajllita',
'qbpageinfo'    => "Uñstawxat uñt'ayawi",
'qbmyoptions'   => 'Ajllitanakaja',
'moredotdotdot' => 'Yapa...',
'mypage'        => 'Uñstawija',
'navigation'    => 'Wampuña',
'and'           => '-mpi',

'errorpagetitle'    => 'Pantja',
'help'              => 'Yanapaña',
'search'            => 'Thaqaña',
'searchbutton'      => 'Thaqaña',
'go'                => 'Saraña',
'searcharticle'     => 'Saraña',
'history'           => 'Nayra qillqata',
'history_short'     => 'Nayra qillqata',
'info_short'        => "Uñt'ayawi",
'edit'              => 'Turkaña',
'create'            => 'Uñstayaña',
'editthispage'      => 'Aka uñstawi turkaña',
'create-this-page'  => 'Aka uñstawi uñstayaña',
'delete'            => 'Pichaña',
'deletethispage'    => 'Aka uñstawi phiskhuraña',
'undelete_short'    => "{{PLURAL:$1|mayaskiptawi|$1 askiptanakawi}} kutt'ayxaña",
'protect'           => "Jark'aña",
'protect_change'    => 'turkaña',
'protectthispage'   => "Aka uñstawi jark'aña",
'unprotect'         => "Jark'ch'ukiña",
'unprotectthispage' => "Aka uñstawi jark'ch'ukiña",
'newpage'           => 'Machaqa uñstawi',
'talkpage'          => 'Aka uñstawxat tuqisiña',
'talkpagelinktext'  => 'Kutkatasiña',
'specialpage'       => 'Ajalla Uñstawi',
'talk'              => 'Tuqisiwi',
'otherlanguages'    => 'Yaqha arunaka',
'protectedpage'     => "Uñstawi jark'ata",
'jumptonavigation'  => 'wampuña',
'jumptosearch'      => 'thaqaña',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Jichha pacha',
'currentevents-url'    => 'Project:Jichha pacha',
'mainpage'             => 'Nayriri Uñstawi',
'mainpage-description' => 'Nayriri Uñstawi',
'portal'               => 'Jayma punku',
'portal-url'           => 'Project:Jayma punku',

'editsection'    => 'turkaña',
'editold'        => 'turkaña',
'showtoc'        => 'uñachayaña',
'site-rss-feed'  => "$1 ''RSS'' jalsuri",
'site-atom-feed' => "$1 ''Atom'' jalsuri",
'page-rss-feed'  => "\"\$1\" ''RSS'' jalsuri",
'page-atom-feed' => "\"\$1\" ''Atom'' jalsuri",

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Amtachinu',
'nstab-user'     => 'Apnaqiri',
'nstab-image'    => "Q'ipi",
'nstab-help'     => 'Yanapaña',
'nstab-category' => 'Patawi',

# General errors
'error' => 'Pantja',

# Login and logout pages
'loginpagetitle'     => "Qillqt'ayasiña/Entrar",
'login'              => "Qillqt'ayasiña/Entrar",
'userlogin'          => "Qillqt'ayasiña/Entrar",
'logout'             => 'Mistuña',
'userlogout'         => 'Mistuña',
'yourlanguage'       => 'Aru:',
'email'              => "Aru jalayiri (''E-mail'')",
'loginlanguagelabel' => 'Aru: $1',

# Edit pages
'summary'  => 'Juk’aptayawi',
'subject'  => 'Yatsuwi/titulu',
'yourdiff' => 'Jalaqtatanaka',

# Preferences page
'prefs-rc'       => 'Jichha kutikiptatanaka',
'timezoneoffset' => 'Jalaqtata',

# Recent changes
'recentchanges' => 'Jichha kutikiptatanaka',
'show'          => 'uñachayaña',

# Upload
'fileuploadsummary' => 'Uñt’ayawi:',

'license' => 'Iyawsawi:',

# Special:ImageList
'imagelist_date'        => 'Uru jakhu',
'imagelist_user'        => 'Apnaqiri',
'imagelist_description' => 'Uñt’ayawi',

# Image description page
'filehist-user' => 'Apnaqiri',

# Miscellaneous special pages
'move' => 'Qillqaraña',

# Special:Log
'specialloguserlabel'  => 'Apnaqiri:',
'speciallogtitlelabel' => 'Titulu:',
'log-search-submit'    => 'Saraña',

# Special:ListUsers
'listusers-submit' => 'Uñachayaña',

# Watchlist
'watch' => 'Uñjaña',

# Restrictions (nouns)
'restriction-move' => 'Qillqaraña',

# Undelete
'undelete-search-submit' => 'Thaqaña',

'sp-contributions-submit' => 'Thaqaña',

# Block/unblock
'ipblocklist-submit' => 'Thaqaña',
'proxyblocksuccess'  => 'Kamachawi',

# Tooltip help for the actions
'tooltip-p-logo' => 'Nayriri Uñstawi',

# Attribution
'others' => 'yaqha',

# action=purge
'confirm_purge_button' => 'Iyawa saña',

# Multipage image navigation
'imgmultigo' => '¡Saraña!',

# Table pager
'table_pager_limit_submit' => 'Saraña',

);

==> mediawiki-1.14.0rc1.tar.gz: mediawiki-1.14.0rc1/languages/messages/MessagesAy.php <==
<?php
/** Aymara (Aymar aru)
 *
 * @ingroup Language
 * @file
 *
 * @author Erebedhel
 * @author Kanon6917
 */

$fallback = 'es';

$messages = array(
# User preference toggles
'tog-underline'               => 'Sipita siqiraña',
'tog-highlightbroken'         => 'P\'akita sipita utt\'ayaña <a href="" class="new">ukhama</a> (maykipa: ukhama<a href="" class="internal">?</a>).',
'tog-justify'                 => "Tanta amuyanak purapt'ayaña",
'tog-hideminor'               => 'Jichha kutikiptatanakana «Janiw taqpachäkiti» imantaña',
'tog-extendwatchlist'         => "Sarayawi jaqukipaw uñachayasuñatakiw unch'ukit waruch aqatatayaña",
'tog-usenewrc'                => "Jichhnaki jaqukipawi waliptäta (''JavaScript'')",
'tog-numberheadings'          => 'Titulun chinu achuraña',
'tog-showtoolbar'             => "Turkawit irnaqañ täta tisi uñachayaña (''JavaScript'')",
'tog-editondblclick'          => "Uñstawi turkayaña päsuxuqiña (''JavaScript'')",
'tog-editsection'             => '[Turkaña] sipitampi tuqitaki turkawi luräña',
'tog-editsectiononrightclick' => "(''JavaScript'') titulxat tuqina kupi suxuqiñampi tuqitaki turkawi luräña",
'tog-showtoc'                 => 'Waruchataw uñachayaña (kimsa tituljampi uñstawitaki)',
'tog-rememberpassword'        => "Akax jasanchirin imt'awija amtaña",

'underline-always' => 'Wiñaya',
'underline-never'  => 'Janipini',

# Dates
'sunday'        => 'tuminku',
'monday'        => 'lunisa',
'tuesday'       => 'martisa',
'wednesday'     => 'mirkulisa',
'thursday'      => 'juywisa',
'friday'        => 'wirnisa',
'saturday'      => 'sawaru',
'sun'           => 'tum',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mir',
'thu'           => 'juy',
'fri'           => 'wir',
'sat'           => 'saw',
'january'       => 'chichu phaxsi',
'february'      => 'anata phaxsi',
'march'         => 'achuqa phaxsi',
'april'         => 'yapu apthapi phaxsi',
'may_long'      => 'llamayu phaxsi',
'june'          => 'juyphi phaxsi',
'july'          => 'huillka kuti phaxsi',
'august'        => 'thaya phaxsi',
'september'     => "llamp'u phaxsi",
'october'       => 'taypi sata phaxsi',
'november'      => 'awti phaxsi',
'december'      => 'jallu qallta phaxsi',
'january-gen'   => 'chichu phaxsi',
'february-gen'  => 'anata phaxsi',
'march-gen'     => 'achuqa phaxsi',
'april-gen'     => 'yapu apthapi phaxsi',
'may-gen'       => 'llamayu phaxsi',
'june-gen'      => 'juyphi phaxsi',
'july-gen'      => 'huillka kuti phaxsi',
'august-gen'    => 'thaya phaxsi',
'september-gen' => "llamp'u phaxsi",
'october-gen'   => 'taypi sata phaxsi',
'november-gen'  => 'awti phaxsi',
'december-gen'  => 'jallu qallta phaxsi',
'jan'           => 'chi',
'feb'           => 'ana',
'mar'           => 'ach',
'apr'           => 'yap',
'may'           => 'llam',
'jun'           => 'juy',
'jul'           => 'hui',
'aug'           => 'tha',
'sep'           => 'llmp',
'oct'           => 'tay',
'nov'           => 'awt',
'dec'           => 'jall',

'article'       => 'Amtachinu',
'cancel'        => 'Jan saña',
'qbfind'        => 'Thaqaña',
'qbbrowse'      => 'Wampuña',
'qbedit'        => 'Turkaña',
'qbpageoptions' => 'Uñstawitaki ajllita',
'qbpageinfo'    => "Uñstawxat uñt'ayawi",
'qbmyoptions'   => 'Ajllitanakaja',
'moredotdotdot' => 'Yapa...',
'mypage'        => 'Uñstawija',
'navigation'    => 'Wampuña',
'and'           => '&#32;-mpi',

'errorpagetitle'    => 'Pantja',
'help'              => 'Yanapaña',
'search'            => 'Thaqaña',
'searchbutton'      => 'Thaqaña',
'go'                => 'Saraña',
'searcharticle'     => 'Saraña',
'history'           => 'Nayra qillqata',
'history_short'     => 'Nayra qillqata',
'info_short'        => "Uñt'ayawi",
'edit'              => 'Turkaña',
'create'            => 'Uñstayaña',
'editthispage'      => 'Aka uñstawi turkaña',
'create-this-page'  => 'Aka uñstawi uñstayaña',
'delete'            => 'Pichaña',
'deletethispage'    => 'Aka uñstawi phiskhuraña',
'undelete_short'    => "{{PLURAL:$1|mayaskiptawi|$1 askiptanakawi}} kutt'ayxaña",
'protect'           => "Jark'aña",
'protect_change'    => 'turkaña',
'protectthispage'   => "Aka uñstawi jark'aña",
'unprotect'         => "Jark'ch'ukiña",
'unprotectthispage' => "Aka uñstawi jark'ch'ukiña",
'newpage'           => 'Machaqa uñstawi',
'talkpage'          => 'Aka uñstawxat tuqisiña',
'talkpagelinktext'  => 'Kutkatasiña',
'specialpage'       => 'Ajalla Uñstawi',
'talk'              => 'Tuqisiwi',
'otherlanguages'    => 'Yaqha arunaka',
'protectedpage'     => "Uñstawi jark'ata",
'jumptonavigation'  => 'wampuña',
'jumptosearch'      => 'thaqaña',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Jichha pacha',
'currentevents-url'    => 'Project:Jichha pacha',
'mainpage'             => 'Nayriri Uñstawi',
'mainpage-description' => 'Nayriri Uñstawi',
'portal'               => 'Jayma punku',
'portal-url'           => 'Project:Jayma punku',

'editsection'    => 'turkaña',
'editold'        => 'turkaña',
'editlink'       => 'trukaña',
'showtoc'        => 'uñachayaña',
'site-rss-feed'  => "$1 ''RSS'' jalsuri",
'site-atom-feed' => "$1 ''Atom'' jalsuri",
'page-rss-feed'  => "\"\$1\" ''RSS'' jalsuri",
'page-atom-feed' => "\"\$1\" ''Atom'' jalsuri",

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Amtachinu',
'nstab-user'     => 'Apnaqiri',
'nstab-image'    => "Q'ipi",
'nstab-help'     => 'Yanapaña',
'nstab-category' => 'Patawi',

# General errors
'error' => 'Pantja',

# Login and logout pages
'loginpagetitle'     => "Qillqt'ayasiña/Entrar",
'login'              => "Qillqt'ayasiña/Entrar",
'userlogin'          => "Qillqt'ayasiña/Entrar",
'logout'             => 'Mistuña',
'userlogout'         => 'Mistuña',
'yourlanguage'       => 'Aru:',
'email'              => "Aru jalayiri (''E-mail'')",
'loginlanguagelabel' => 'Aru: $1',

# Edit pages
'summary'  => 'Juk’aptayawi:',
'subject'  => 'Yatsuwi/titulu:',
'yourdiff' => 'Jalaqtatanaka',

# Preferences page
'prefs-rc'       => 'Jichha kutikiptatanaka',
'timezoneoffset' => 'Jalaqtata',

# Recent changes
'recentchanges' => 'Jichha kutikiptatanaka',
'show'          => 'uñachayaña',

# Upload
'fileuploadsummary' => 'Uñt’ayawi:',

'license' => 'Iyawsawi:',

# Special:ListFiles
'listfiles_date'        => 'Uru jakhu',
'listfiles_user'        => 'Apnaqiri',
'listfiles_description' => 'Uñt’ayawi',

# File description page
'filehist-user' => 'Apnaqiri',

# Miscellaneous special pages
'move' => 'Qillqaraña',

# Special:Log
'specialloguserlabel'  => 'Apnaqiri:',
'speciallogtitlelabel' => 'Titulu:',

# Special:ListUsers
'listusers-submit' => 'Uñachayaña',

# Watchlist
'watch' => 'Uñjaña',

# Restrictions (nouns)
'restriction-move' => 'Qillqaraña',

# Undelete
'undelete-search-submit' => 'Thaqaña',

'sp-contributions-submit' => 'Thaqaña',

# Block/unblock
'ipblocklist-submit' => 'Thaqaña',
'proxyblocksuccess'  => 'Kamachawi',

# Tooltip help for the actions
'tooltip-p-logo' => 'Nayriri Uñstawi',

# Attribution
'others' => 'yaqha',

# action=purge
'confirm_purge_button' => 'Iyawa saña',

# Multipage image navigation
'imgmultigo' => '¡Saraña!',

# Table pager
'table_pager_limit_submit' => 'Saraña',

);
